@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: iso-8859-1 -*-
 
 import pygtk
 pygtk.require('2.0')
@@ -966,9 +967,9 @@ class View(gtk.Window):
 
         if wrap_mode == gtk.WRAP_NONE:
             menu_item = self.item_factory.get_widget("/Settings/Wrap Off")
-        elif direction == gtk.WRAP_WORD:
+        elif wrap_mode == gtk.WRAP_WORD:
             menu_item = self.item_factory.get_widget("/Settings/Wrap Words")
-        elif direction == gtk.WRAP_CHAR:
+        elif wrap_mode == gtk.WRAP_CHAR:
             menu_item = self.item_factory.get_widget("/Settings/Wrap Chars")
 
         if menu_item:
